﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinSchedule;

namespace WS_ReadOnlyOwner
{
    public partial class Form1 : Form
    {
        List<Owner> disabledOwners;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            disabledOwners = new List<Owner>();

            ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;

            ultraCalendarInfo1.Owners.Add("Joe");
            ultraCalendarInfo1.Owners.Add("Kate");
            ultraCalendarInfo1.Owners.Add("Frank");

            ultraCalendarInfo1.Appointments.Add(new Appointment(DateTime.Now, 
                DateTime.Now.AddHours(1))).OwnerKey = "Joe";
            ultraCalendarInfo1.Appointments.Add(new Appointment(DateTime.Now,
                DateTime.Now.AddHours(1))).OwnerKey = "Kate";
            ultraCalendarInfo1.Appointments.Add(new Appointment(DateTime.Now,
                DateTime.Now.AddHours(1))).OwnerKey = "Frank";

            ultraDayView1.EnsureTimeSlotVisible(DateTime.Now, true);

            ultraDayView1.GroupingStyle = DayViewGroupingStyle.OwnerWithinDate;

          
        }

        private void ultraDayView1_AppointmentsDragging(object sender, AppointmentsDraggingEventArgs e)
        {
            e.Cancel = IsAppointmentOwnerDisabled(e.Appointments);
        }

        private bool IsAppointmentOwnerDisabled(IEnumerable<Appointment> appointments)
        {
            return appointments.Any(a => disabledOwners.Contains(a.Owner));
        }

        private bool IsAppointmentOwnerDisabled(Appointment appointments)
        {
            return disabledOwners.Contains(appointments.Owner);
        }

        private void checkBox_CheckChanged(object sender, EventArgs e)
        {
            UltraCheckEditor checkEditor = sender as UltraCheckEditor;

            if (checkEditor.Checked)
            {
                disabledOwners.Add(ultraCalendarInfo1.Owners[checkEditor.Text]);
            }
            else
            {
                disabledOwners.Remove(ultraCalendarInfo1.Owners[checkEditor.Text]);
            }
        }

        private void ultraDayView1_BeforeAppointmentEdited(object sender, CancelableAppointmentEventArgs e)
        {
            e.Cancel = IsAppointmentOwnerDisabled(e.Appointment);
        }

        private void ultraDayView1_BeforeAppointmentResized(object sender, BeforeAppointmentResizedEventArgs e)
        {
            e.Cancel = IsAppointmentOwnerDisabled(e.Appointment);
        }

        private void ultraDayView1_BeforeAppointmentsDeleted(object sender, BeforeAppointmentsDeletedEventArgs e)
        {
            e.Cancel = IsAppointmentOwnerDisabled(e.Appointments);
        }

        private void ultraDayView1_BeforeAppointmentsMoved(object sender, CancelableAppointmentsEventArgs e)
        {
            e.Cancel = IsAppointmentOwnerDisabled(e.Appointments);
        }

        private void ultraCalendarInfo1_BeforeDisplayAppointmentDialog(object sender, DisplayAppointmentDialogEventArgs e)
        {
            e.Cancel = disabledOwners.Contains(ultraDayView1.ActiveOwner);
        }

    }
}
